%define anolis_release 1

%bcond_with oscilloscope

Name:                   tuna
Version:                0.19
Release:                %{anolis_release}%{?dist}
License:                GPL-2.0-only AND LGPL-2.1-only
Summary:                Application tuning GUI & command line utility
URL:                    https://rt.wiki.kernel.org/index.php/Tuna
Source0:                https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.xz

BuildRequires:          python3-devel gettext
Requires:               python3-ethtool python3-linux-procfs >= 0.6 python3-schedutils >= 0.6
BuildArch:              noarch

# https://web.git.kernel.org/pub/scm/utils/tuna/tuna.git/commit/?id=fbde2418c84e57723ae1698acfe5932a11f4d611
Patch1: 0001-Add-SPDX-license-identifiers.patch
# https://web.git.kernel.org/pub/scm/utils/tuna/tuna.git/commit/?id=0c93bd0f26c3d7abda51e51a43ea979ecd794cc9
Patch2: 0002-tuna-Remove-spec-file-from-git.patch
# https://web.git.kernel.org/pub/scm/utils/tuna/tuna.git/commit/?id=5c2ff1e15bbce8d76a038de55abc20e8b3164bb7
Patch3: tuna-Don-t-start-the-gui-if-a-display-is-not-availab.patch

%description
The program can be used to change the attributes of application and kernel threads. 
Tuna can operate on IRQs by name or number, and tasks or threads by process ID or 
command-line. CPUs and sets of CPUs can be specified by CPU or socket number. 
IRQ names and process command-lines can include wildcards.


%if %{with oscilloscope}
%package -n oscilloscope
Summary:        Generic signal tool graphical plotting
Requires:       python3-matplotlib-gtk3 python3-numpy python3-cairocffi  gobject-introspection
Requires:       %{name} = %{version}-%{release}

%description -n oscilloscope
This package provides plots stream of values read from standard input on the
screen together with statistics and a histogram.
%endif

%package doc
Summary:        Documentry files for tuna
Requires:       %{name} = %{version}-%{release}
License:        GPLv2
BuildArch:      noarch

%description doc
This package provides documentary files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1 


%build
%py3_build
%py3_shebang_fix tuna/
%py3_shebang_fix tuna-cmd.py
%if %{with oscilloscope}
%py3_shebang_fix oscilloscope-cmd.py
%endif


%install
rm -rf %{buildroot}
%py3_install
mkdir -p %{buildroot}/%{_sysconfdir}/tuna/
mkdir -p %{buildroot}/{%{_bindir},%{_datadir}/tuna/help/kthreads,%{_mandir}/man8}
mkdir -p %{buildroot}/%{_datadir}/polkit-1/actions/

install -m 0644 -p tuna/tuna_gui.glade %{buildroot}/%{_datadir}/tuna/
install -m 0755 -p tuna-cmd.py %{buildroot}/%{_bindir}/tuna
install -m 0644 -p help/kthreads/* %{buildroot}/%{_datadir}/tuna/help/kthreads/
install -m 0644 -p docs/tuna.8 %{buildroot}/%{_mandir}/man8/
install -m 0644 -p etc/tuna/example.conf %{buildroot}/%{_sysconfdir}/tuna/
install -m 0644 -p etc/tuna.conf %{buildroot}/%{_sysconfdir}/
install -m 0644 -p org.tuna.policy %{buildroot}/%{_datadir}/polkit-1/actions/
%if %{with oscilloscope}
install -m 0755 -p oscilloscope-cmd.py %{buildroot}/%{_bindir}/oscilloscope
%endif

for lng in `cat po/LINGUAS`
do
        po=po/"$lng.po"
        mkdir -p %{buildroot}/%{_datadir}/locale/${lng}/LC_MESSAGES
        msgfmt $po -o %{buildroot}/%{_datadir}/locale/${lng}/LC_MESSAGES/%{name}.mo
done


%find_lang %name


%files -f %{name}.lang
%{_sysconfdir}/tuna.conf
%{_sysconfdir}/tuna/*
%{_bindir}/tuna
%{python3_sitelib}/tuna/
%{python3_sitelib}/*.egg-info
%{_datadir}/tuna/
%{_datadir}/polkit-1/actions/org.tuna.policy
%{_mandir}/man8/tuna.8*


%if %{with oscilloscope}
%files -n oscilloscope
%{_bindir}/oscilloscope
%endif


%files doc
%doc ChangeLog
%if %{with oscilloscope}
%doc docs/oscilloscope+tuna.html
%doc docs/oscilloscope+tuna.pdf
%endif

%changelog
* Wed Feb 26 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.19-1
- Update to 0.19 from 0.18
- Add patches to use SPDX license identifiers
- Add patches to remove spec file from git
- Add patches to don't start the gui if a display is not available
  [Patches cherry-picked from c10s. Original changelog:
  - Bump release for October 2024 mass rebuild:(0.19-9)]

* Mon Mar 11 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 0.18-3
- Rebuild with python3.11

* Thu Apr 13 2023 chen_yu_ao <m15927509890@163.com> - 0.18-2
- change spec file format

* Fri Dec 23 2022 Feng Su <sufeng@linux.alibaba.com> - 0.18-1
- initial  packaging for Anolis 23
